@@ -1,7 +1,7 @@
 """
 Type annotations for shield service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     ApplicationLayerAutomaticResponseStatusType,
     AttackLayerType,
@@ -71,10 +73,12 @@ __all__ = (
     "EnableApplicationLayerAutomaticResponseRequestRequestTypeDef",
     "GetSubscriptionStateResponseTypeDef",
     "LimitTypeDef",
+    "ListAttacksRequestListAttacksPaginateTypeDef",
     "ListAttacksRequestRequestTypeDef",
     "ListAttacksResponseTypeDef",
     "ListProtectionGroupsRequestRequestTypeDef",
     "ListProtectionGroupsResponseTypeDef",
+    "ListProtectionsRequestListProtectionsPaginateTypeDef",
     "ListProtectionsRequestRequestTypeDef",
     "ListProtectionsResponseTypeDef",
     "ListResourcesInProtectionGroupRequestRequestTypeDef",
@@ -454,6 +458,17 @@ LimitTypeDef = TypedDict(
     total=False,
 )
 
+ListAttacksRequestListAttacksPaginateTypeDef = TypedDict(
+    "ListAttacksRequestListAttacksPaginateTypeDef",
+    {
+        "ResourceArns": Sequence[str],
+        "StartTime": "TimeRangeTypeDef",
+        "EndTime": "TimeRangeTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListAttacksRequestRequestTypeDef = TypedDict(
     "ListAttacksRequestRequestTypeDef",
     {
@@ -493,6 +508,14 @@ ListProtectionGroupsResponseTypeDef = TypedDict(
     },
 )
 
+ListProtectionsRequestListProtectionsPaginateTypeDef = TypedDict(
+    "ListProtectionsRequestListProtectionsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListProtectionsRequestRequestTypeDef = TypedDict(
     "ListProtectionsRequestRequestTypeDef",
     {
@@ -636,7 +659,9 @@ ProtectionTypeDef = TypedDict(
         "ResourceArn": str,
         "HealthCheckIds": List[str],
         "ProtectionArn": str,
-        "ApplicationLayerAutomaticResponseConfiguration": "ApplicationLayerAutomaticResponseConfigurationTypeDef",
+        "ApplicationLayerAutomaticResponseConfiguration": (
+            "ApplicationLayerAutomaticResponseConfigurationTypeDef"
+        ),
     },
     total=False,
 )
